@@ -12,13 +12,13 @@ handNames=c("0-1",2:4,"5 or more")
 
 book3<-XLwriteOpen("hands.xls") 
 XLtwoWay(book3,"PartnersAKQcounts",cut(hand1,c(0,2:6,14)-0.5),cut(hand2,c(0,2:5,14)-0.5),
-         rowTitle="Hand 1 vs. Hand 2",rowNames=c(handNames[-5],5,"6 or more","Total"),
+         rowTitle="Hand 1 (rows) vs. Hand 2",rowNames=c(handNames[-5],5,"6 or more","Total"),
          colNames=c(handNames,"Total"),header=TRUE)
 
 ## Same table, but percents now condition on columns rather than rows, 
 ## counts/pct header row removed - but a title added:
 XLtwoWay(book3,"PartnersAKQcounts",cut(hand1,c(0,2:6,14)-0.5),cut(hand2,c(0,2:5,14)-0.5),
-         rowTitle="Hand 1 vs. Hand 2",rowNames=c(handNames[-5],5,"6 or more","Total"),
+         rowTitle="Hand 1 (rows) vs. Hand 2",rowNames=c(handNames[-5],5,"6 or more","Total"),
          colNames=c(handNames,"Total"),header=FALSE,row1=12,sumby=2,
          title="Now Percents are Summed by Column:")
 
